@@ -4,13 +4,13 @@
 *
 ********************************************************************************
 *
-*  $Revision: 4 $
+*  $Revision: 7 $
 *  $Author: mhx $
-*  $Date: 2004/08/13 12:49:24 +0200 $
+*  $Date: 2005/10/18 21:06:49 +0200 $
 *
 ********************************************************************************
 *
-*  Version 3.x, Copyright (C) 2004, Marcus Holland-Moritz.
+*  Version 3.x, Copyright (C) 2004-2005, Marcus Holland-Moritz.
 *  Version 2.x, Copyright (C) 2001, Paul Marquess.
 *  Version 1.x, Copyright (C) 1999, Kenneth Albanowski.
 *
@@ -23,10 +23,20 @@
 #include "perl.h"
 #include "XSUB.h"
 
+#ifndef PATCHLEVEL
+#include "patchlevel.h"
+#endif
+
 #define NEED_newCONSTSUB_GLOBAL
+#define NEED_PL_signals_GLOBAL
 #include "ppport.h"
 
 void call_newCONSTSUB_2(void)
 {
   newCONSTSUB(gv_stashpv("Devel::PPPort", FALSE), "test_value_2", newSViv(2));
 }
+
+U32 get_PL_signals_2(void)
+{
+  return PL_signals;
+}
